

#ifndef _I2CRTC_H			//??
#define _I2CRTC_H			//??

//------------- RTC-I2C-Adress --------------*

#define RTC_I2C_DEVICE		0x67	    /**< Change this to the address of your expander */


#define RTC_ADDRESS			0	//??	//Used for reading the address-counter and busy-flag
#define RTC_DATA			1	//??	//Used for reading data

/*------------- RTC-Register-Addresses -------------*/

//Status+Generalconfig-Register
 
	#define RTC_Status			0x0E	// RTC-Status-Register 
	#define RTC_DCF77_config	0x0D	// DCF77-Config- Register
	
//Time-Register
	#define RTC_second			0x00	//Second of Time
	#define RTC_minute			0x01	//Minute of Time
	#define RTC_hour			0x02	//Hour of Time
	#define RTC_week_day		0x03	//What day of the week
	#define RTC_day				0x04	//Day of month
	#define RTC_month			0x05	//Month of the year
	#define RTC_year			0x06	//What year

// Alarm-Register 
	#define RTC_ARLAM_minute			0x07	//Alarm minute
	#define RTC_ALARM_hour				0x08	//Alarm hour
	#define RTC_ALARM_week_day			0x09	//Alarm weekday
	#define RTC_ALARM_config			0x0B	//Alarm-Config-Register
 

// Interrupt-Register
 
	#define RTC_periodic_int			0x0A	//periodic-interrupt
	#define RTC_per_int_conig			0x0C	//periodic-interrupt-config-register


/*------------- Bits of registers -------------*/

//Alarm-weekday

	#define AWSU						0x64	//Sunday
	#define AWSA						0x32	//Saturday
	#define AWFR						0x16	//Friday
	#define AWTH						0x08	//Thursday
	#define AWWE						0x04	//Wednesday
	#define AWTU						0x02	//Tuesday
	#define AWMO						0x01	//Monday

//Periodic-Interrupt-Register

	#define PIM0						0x00	//1 Hz
	#define PIM1						0x01	//2 Hz
	#define PIM2						0x02	//every second
	#define PIM3						0x03	//every minute
	#define PIM4						0x04	//every hour
	#define PIM5						0x05	//every day, at 0 OClock
	#define PIM6						0x06	//every month, on the 1.st at 0 OClock 

//Alarm-Config-Register

	#define AILED						0x04	// LED on, when Alarm Interrupts 
	#define AIE							0x02	// Alarm Interrupt enable

//Periodic-Interrupt-Config-Register

	#define PILED						0x04	//LED on, when Interrupt
	#define PIE							0x02	//periodic Interrupt enabel

//DCF77-Config-Register

	#define DCFLED						0x04	//LED on, when DCF77 signal
	#define DCFIE						0x02	//Interrupt enable when DFC77 signal
	#define DCFE						0x01	//DCF-receiver enable

//Status-Register

	#define AIF							0x04	//Alarm Interrupt Flag
	#define PIF							0x02	//Periodic Interrupt Flag
	#define DCFIF						0x01	//DCF-revive Interrupt Flag

/*------------- I2C - Functions -------------*/

/**
 \brief Write data to i2c (for internal use)
 \param value byte to send over i2c
 \return none
 */
void rtc_write_i2c(uint8_t value);

/**
 \brief Write nibble to RTC with toggle of enable-bit
 */
void rtc_write(uint8_t value);

/**
 \brief Read data from i2c (for internal use)
 \retval "uint8_t" byte received over i2c
 */
uint8_t rtc_read_i2c(void);

/**
 \brief Read data from RTC over i2c (for internal use)
 */
uint8_t rtc_read(bool mode);

/**
 \brief Read one byte over i2c from RTC
 \param mode ADDRESS for cursor address and busy flag or DATA for display data
 \retval "uint8_t" the byte received from the RTC
 */
uint8_t rtc_getbyte(bool mode);


//-FUNCTIONS---------------------------------------------------------------------------------------------------------

void rtc_init(void);

void rtc_command(uint8_t command);

bool rtc_busy(void);


#endif
